@@ -551,7 +551,7 @@ class RedisRoot:
                             if value is not None:
                                 value = value.model
                                 if value is not None:
-                                    value = get_or_create_redis_model_from_django_model(value, redis_root)
+                                    value = get_or_create_redis_model_from_django_model(value, redis_root, save_related_models)
                                     if value is not None:
                                         allowed_redis_params[redis_field_param_name] = value
                                         allowed_redis_params['save_related_models'] = save_related_models
